==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/ManagementGovernance/ServiceUserPrivacy.md <==
# ServiceUserPrivacy


```text
azure-4/Item/ManagementGovernance/ServiceUserPrivacy
```

```text
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')
```



| Illustration | ServiceUserPrivacy | ServiceUserPrivacyCard | ServiceUserPrivacyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacy.png) | ![illustration for ServiceUserPrivacy](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacy.Local.png) | ![illustration for ServiceUserPrivacyCard](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacyCard.Local.png) | ![illustration for ServiceUserPrivacyGroup](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacyGroup.Local.png) |




## ServiceUserPrivacy

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacy
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacy('ServiceUserPrivacy', 'Service User Privacy', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacy
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacy('ServiceUserPrivacy', 'Service User Privacy', 'an optional tech label')
@enduml
```

## ServiceUserPrivacyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyCard
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyCard('ServiceUserPrivacyCard', 'Service User Privacy Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyCard
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyCard('ServiceUserPrivacyCard', 'Service User Privacy Card', 'an optional description')
@enduml
```

## ServiceUserPrivacyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyGroup
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyGroup('ServiceUserPrivacyGroup', 'Service User Privacy Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyGroup
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyGroup('ServiceUserPrivacyGroup', 'Service User Privacy Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/ManagementGovernance/ServiceUserPrivacy.md <==
# ServiceUserPrivacy


```text
azure-4/Item/ManagementGovernance/ServiceUserPrivacy
```

```text
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')
```



| Illustration | ServiceUserPrivacy | ServiceUserPrivacyCard | ServiceUserPrivacyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacy.png) | ![illustration for ServiceUserPrivacy](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacy.Local.png) | ![illustration for ServiceUserPrivacyCard](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacyCard.Local.png) | ![illustration for ServiceUserPrivacyGroup](../../../azure-4/Item/ManagementGovernance/ServiceUserPrivacyGroup.Local.png) |




## ServiceUserPrivacy

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacy
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacy('ServiceUserPrivacy', 'Service User Privacy', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacy
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacy('ServiceUserPrivacy', 'Service User Privacy', 'an optional tech label')
@enduml
```

## ServiceUserPrivacyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyCard
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyCard('ServiceUserPrivacyCard', 'Service User Privacy Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyCard
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyCard('ServiceUserPrivacyCard', 'Service User Privacy Card', 'an optional description')
@enduml
```

## ServiceUserPrivacyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyGroup
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyGroup('ServiceUserPrivacyGroup', 'Service User Privacy Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceUserPrivacyGroup
include('azure-4/Item/ManagementGovernance/ServiceUserPrivacy')

' renders the element
ServiceUserPrivacyGroup('ServiceUserPrivacyGroup', 'Service User Privacy Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
